Import

Struct Import 

pub struct Import {
    pub element: String,
    pub is_directive: bool,
    pub alias: Option<String>,
}

Fields

element: String

The name of the element that is being imported.

Note that this will never start with ‘@’: whether or not this is the name of a directive is entirely reflected by the value of is_directive.

is_directive: bool

Whether the imported element is a directive (if it is not, then it is an imported type).

alias: Option<String>

The optional alias under which the element is imported.

Implementations