pub struct Import {
pub element: String,
pub is_directive: bool,
pub alias: Option<String>,
}Fields
element: StringThe name of the element that is being imported.
Note that this will never start with ‘@’: whether or not this is the name of a directive is
entirely reflected by the value of is_directive.
is_directive: boolWhether the imported element is a directive (if it is not, then it is an imported type).
alias: Option<String>The optional alias under which the element is imported.
Implementations
Sourceimpl Import
impl Import
pub fn from_hir_value(value: &Value) -> Result<Import, LinkError>
pub fn imported_name(&self) -> &String
pub fn imported_display_name(&self) -> String