pub struct Version {
pub major: u32,
pub minor: u32,
}Expand description
The version of a @link specification, in the form of a major and minor version numbers.
Fields
major: u32The major number part of the version.
minor: u32The minor number part of the version.
Implementations
Sourceimpl Version
impl Version
Sourcepub fn satisfies(&self, required: &Version) -> bool
pub fn satisfies(&self, required: &Version) -> bool
Whether this version satisfies the provided required version.
assert!(&Version { major: 1, minor: 0 }.satisfies(&Version{ major: 1, minor: 0 }));
assert!(&Version { major: 1, minor: 2 }.satisfies(&Version{ major: 1, minor: 0 }));
assert!(!(&Version { major: 2, minor: 0 }.satisfies(&Version{ major: 1, minor: 9 })));
assert!(!(&Version { major: 0, minor: 9 }.satisfies(&Version{ major: 0, minor: 8 })));Sourcepub fn satisfies_range(&self, min: &Version, max: &Version) -> bool
pub fn satisfies_range(&self, min: &Version, max: &Version) -> bool
Verifies whether this version satisfies the provided version range.
Panics
The min and max must be the same major version, and max minor version must be higher than min’s.
Else, you get a panic.
Examples
assert!(&Version { major: 1, minor: 1 }.satisfies_range(&Version{ major: 1, minor: 0 }, &Version{ major: 1, minor: 10 }));
assert!(!&Version { major: 2, minor: 0 }.satisfies_range(&Version{ major: 1, minor: 0 }, &Version{ major: 1, minor: 10 }));Trait Implementations
Sourceimpl Ord for Version
impl Ord for Version
Sourceimpl PartialOrd for Version
impl PartialOrd for Version
impl Eq for Version
impl StructuralPartialEq for Version